close all

%% LOAD MODEL AND DATA
Model = 'Macrophage_simple';
optModel = IQMmodel(strcat(Model,'.txt'));
IQMmakeMEXmodel(optModel,Model);
paramNames = IQMparameters(optModel);
statenames = IQMstates(Model);
initCon = IQMinitialconditions(optModel);

LoadData;
LoadDrugData;
TNF_Timepoints = DRUGDATA.timepoints;
TNF_Timepoints2 = DRUGDATA.timepoints2;

%% DEFINE COLORS
LPS0 = [0,0,0]; %black
LPS100 = [230,159,0]./256; %orange
LPS1000 = [240,228,66]./256; %yellow
dexa03_pre = [204,121,167]./256; %purple pink
dexa03 = [213,94,0]./256; %red
dexa3_pre3 = [86,180,233]./256; %sky blue
dexa3 = [0,114,178]./256; %blue
dexa3_pre2 = [0,158,115]./256; %green
dexa3_pre1 = [80,0,0]./256; %brown

%% LOAD PARAMS
load values_estdata.mat
values = values_estdata;
thres = 52; %chi2inv(0.95,37)

ind=find(values(:,1)<thres);

%select resolution (for speed select higher value)
res = 200;

all_param = ones(round(size(ind,1)/res), size(values,2));
size(all_param)

l=1;


for i = 1:res:size(ind, 1)
    

    all_p = values(ind(i),:);
    X = all_p(2:end-1);
    
    cost=all_p(1);
    
    scale = all_p(end);
    
    all_param(1+(i-1)/res,:) = all_p(:);
    
    X = [X, 0, 0];
    
    ss_simulation = IQMPsimulate(Model, 700, initCon, paramNames, X);
    ss_simulation.statevalues(end, end) = 0; %TNFa 0 at experiment start
    
    %LPS only
    X(end) = 0;
    X(end-1) = 0;
    LPS_0_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 10;
    LPS_10_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 50;
    LPS_50_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 100;
    LPS_100_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 250;
    LPS_250_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 500;
    LPS_500_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    X(end-1) = 1000;
    LPS_1000_simulation = IQMPsimulate(Model, 24, ss_simulation.statevalues(end,:), paramNames, X);
    
    %PRE-TREATMENT DEXA
    X(end-1) = 0;
    X(end) = 0.3;
    Dexa_simulation_pre300 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, X);
    X(end) = 3;
    Dexa_simulation_pre3000 = IQMPsimulate(Model, 1, ss_simulation.statevalues(end,:), paramNames, X);

    %%addition of 100 ng/ml LPS
    X(end-1) = 100;
    X(end) = 0;
    Dexa_simulation = IQMPsimulate(Model, 25, ss_simulation.statevalues(end,:), paramNames, X);
    X(end) = 0.3;
    Dexa_simulation_pre300.statevalues(end,end) = 0; %TNFa 
    Model_simulation2 = IQMPsimulate(Model, 25, Dexa_simulation_pre300.statevalues(end ,:), paramNames, X);
    X(end) = 3;
    Dexa_simulation_pre3000.statevalues(end,end) = 0; %TNFa
    Model_simulation3 = IQMPsimulate(Model, 25, Dexa_simulation_pre3000.statevalues(end, :), paramNames, X);
    X(end) = 0;
    Model_simulation4 = IQMPsimulate(Model, 25, Dexa_simulation_pre300.statevalues(end,:), paramNames, X);
    X(end) = 0;
    Model_simulation5 = IQMPsimulate(Model, 25, Dexa_simulation_pre3000.statevalues(end, :), paramNames, X);

    % Dexa pretreatment
    X = X(1:(end-2));
    X = [X, 0, 3]; %% Addition of 3 ug Dexa for 1 hour, no LPS
    one_hour_sim = IQMPsimulate(Model, 1, ss_simulation.statevalues(end, :), paramNames, X); 
    one_hour_sim.statevalues(end,end) = 0; %TNFa = 0
    X(end) = 0; %% 22 hours without dexa nor LPS
    twentytwo_hour_sim = IQMPsimulate(Model, 22, one_hour_sim.statevalues(end,:), paramNames, X);
    X(end-1) = 100; %% Trigger an inflammatory effect with LPS. 
    twentytwo_hour_sim.statevalues(end,end) = 0; %%TNFa = 0
    pre1_sim = IQMPsimulate(Model, 7, twentytwo_hour_sim.statevalues(end,:), paramNames, X);
    X = X(1:(end-2));
    X = [X, 0, 0];
    sixteen_hour_sim = IQMPsimulate(Model, 16, one_hour_sim.statevalues(end,:), paramNames, X);
    X = X(1:(end-2));
    X = [X, 100, 0];
    sixteen_hour_sim.statevalues(end,end) = 0; %TNFa = 0
    pre2_sim = IQMPsimulate(Model, 7, sixteen_hour_sim.statevalues(end,:), paramNames, X);
    X = X(1:(end-2));
    X = [X, 100, 0];
    pre3_sim = IQMPsimulate(Model, 7, one_hour_sim.statevalues(end,:), paramNames, X);
        
    if l == 1
        
        l = 2;
        
        LPS_10_min = LPS_10_simulation.variablevalues(end,2);
        LPS_10_max = LPS_10_simulation.variablevalues(end,2);
        LPS_50_min = LPS_50_simulation.variablevalues(end,2);
        LPS_50_max = LPS_50_simulation.variablevalues(end,2);
        LPS_100_min = LPS_100_simulation.variablevalues(end,2);
        LPS_100_max = LPS_100_simulation.variablevalues(end,2);
        LPS_250_min = LPS_250_simulation.variablevalues(end,2);
        LPS_250_max = LPS_250_simulation.variablevalues(end,2);
        LPS_500_min = LPS_500_simulation.variablevalues(end,2);
        LPS_500_max = LPS_500_simulation.variablevalues(end,2);
        LPS_1000_min = LPS_1000_simulation.variablevalues(end,2);
        LPS_1000_max = LPS_1000_simulation.variablevalues(end,2);
        
        LPS_0_min = LPS_0_simulation.variablevalues(:,2);
        LPS_0_max = LPS_0_simulation.variablevalues(:,2);
        LPS_100_x_min = LPS_100_simulation.variablevalues(:,2);
        LPS_100_x_max = LPS_100_simulation.variablevalues(:,2);
        LPS_1000_x_min = LPS_1000_simulation.variablevalues(:,2);
        LPS_1000_x_max = LPS_1000_simulation.variablevalues(:,2);
        
        Dexa_min = scale.*Dexa_simulation.variablevalues(:,2);
        Dexa_max = scale.*Dexa_simulation.variablevalues(:,2);
        sim2_min = scale.*Model_simulation2.variablevalues(:,2);
        sim2_max = scale.*Model_simulation2.variablevalues(:,2);
        sim3_min = scale.*Model_simulation3.variablevalues(:,2);
        sim3_max = scale.*Model_simulation3.variablevalues(:,2);
        sim4_min = scale.*Model_simulation4.variablevalues(:,2);
        sim4_max = scale.*Model_simulation4.variablevalues(:,2);
        sim5_min = scale.*Model_simulation5.variablevalues(:,2);
        sim5_max = scale.*Model_simulation5.variablevalues(:,2);
        
        pre1_min = scale.*pre1_sim.variablevalues(:,2);
        pre1_max = scale.*pre1_sim.variablevalues(:,2);
        pre2_min = scale.*pre2_sim.variablevalues(:,2);
        pre2_max = scale.*pre2_sim.variablevalues(:,2);
        pre3_min = scale.*pre3_sim.variablevalues(:,2);
        pre3_max = scale.*pre3_sim.variablevalues(:,2);
        
        %TNF mRNA
        basal = 0; %one_hour_sim.statevalues(1,8);
        maxi = 1; %one_hour_sim.statevalues(end,8);
        one_max = (one_hour_sim.statevalues(:,8)-basal)./maxi;
        one_min = (one_hour_sim.statevalues(:,8)-basal)./maxi;
        twentytwo_max = (twentytwo_hour_sim.statevalues(:,8)-basal)./maxi;
        twentytwo_min = (twentytwo_hour_sim.statevalues(:,8)-basal)./maxi;
        p1n_min = (pre1_sim.statevalues(:,8)-basal)./maxi;
        p1n_max = (pre1_sim.statevalues(:,8)-basal)./maxi;
        p2n_min = (pre2_sim.statevalues(:,8)-basal)./maxi;
        p2n_max = (pre2_sim.statevalues(:,8)-basal)./maxi;
        p3n_min = (pre3_sim.statevalues(:,8)-basal)./maxi;
        p3n_max = (pre3_sim.statevalues(:,8)-basal)./maxi;
        
        %IKB
        basal = 0;
        maxi = one_hour_sim.statevalues(1,5);
        IKB0_max = (one_hour_sim.statevalues(:,5)-basal)./maxi;
        IKB0_min = (one_hour_sim.statevalues(:,5)-basal)./maxi;
        IKB22_max  = (twentytwo_hour_sim.statevalues(:,5)-basal)./maxi;
        IKB22_min = (twentytwo_hour_sim.statevalues(:,5)-basal)./maxi;
        IKBbrown_max = (LPS_100_simulation.statevalues(:,5)-basal)./maxi;
        IKBbrown_min = (LPS_100_simulation.statevalues(:,5)-basal)./maxi;
        IKBpink_max = (Model_simulation5.statevalues(:,5)-basal)./maxi;
        IKBpink_min = (Model_simulation5.statevalues(:,5)-basal)./maxi;
        IKBviolet_max = (pre2_sim.statevalues(:,5)-basal)./maxi;
        IKBviolet_min = (pre2_sim.statevalues(:,5)-basal)./maxi;
        IKBblue_max = (pre1_sim.statevalues(:,5)-basal)./maxi;
        IKBblue_min = (pre1_sim.statevalues(:,5)-basal)./maxi;
        IKBgreen_max = (Model_simulation3.statevalues(:,5)-basal)./maxi;
        IKBgreen_min = (Model_simulation3.statevalues(:,5)-basal)./maxi;        

    else    

        LPS_10_min = min(LPS_10_simulation.variablevalues(end,2), LPS_10_min);
        LPS_10_max = max(LPS_10_simulation.variablevalues(end,2), LPS_10_max);
        LPS_50_min = min(LPS_50_simulation.variablevalues(end,2), LPS_50_min);
        LPS_50_max = max(LPS_50_simulation.variablevalues(end,2), LPS_50_max);
        LPS_100_min = min(LPS_100_simulation.variablevalues(end,2), LPS_100_min);
        LPS_100_max = max(LPS_100_simulation.variablevalues(end,2), LPS_100_max);
        LPS_250_min = min(LPS_250_simulation.variablevalues(end,2), LPS_250_min);
        LPS_250_max = max(LPS_250_simulation.variablevalues(end,2), LPS_250_max);
        LPS_500_min = min(LPS_500_simulation.variablevalues(end,2), LPS_500_min);
        LPS_500_max = max(LPS_500_simulation.variablevalues(end,2), LPS_500_max);
        LPS_1000_min = min(LPS_1000_simulation.variablevalues(end,2), LPS_1000_min);
        LPS_1000_max = max(LPS_1000_simulation.variablevalues(end,2), LPS_1000_max);
        
        for j = 1:size(LPS_0_min,1)
            LPS_0_min(j) = min(LPS_0_simulation.variablevalues(j,2), LPS_0_min(j));
            LPS_0_max(j) = max(LPS_0_simulation.variablevalues(j,2), LPS_0_max(j));
            LPS_100_x_min(j) = min(LPS_100_simulation.variablevalues(j,2), LPS_100_x_min(j));
            LPS_100_x_max(j) = max(LPS_100_simulation.variablevalues(j,2), LPS_100_x_max(j));
            LPS_1000_x_min(j) = min(LPS_1000_simulation.variablevalues(j,2), LPS_1000_x_min(j));
            LPS_1000_x_max(j) = max(LPS_1000_simulation.variablevalues(j,2), LPS_1000_x_max(j));
        end
        
        for j = 1:size(Dexa_min,1)
            Dexa_min(j)= min(scale.*Dexa_simulation.variablevalues(j,2), Dexa_min(j));
            Dexa_max(j) = max(scale.*Dexa_simulation.variablevalues(j,2), Dexa_max(j));
            sim2_min(j)= min(scale.*Model_simulation2.variablevalues(j,2), sim2_min(j));
            sim2_max(j) = max(scale.*Model_simulation2.variablevalues(j,2), sim2_max(j));
            sim3_min(j) = min(scale.*Model_simulation3.variablevalues(j,2), sim3_min(j));
            sim3_max(j) = max(scale.*Model_simulation3.variablevalues(j,2), sim3_max(j));
            sim4_min(j) = min(scale.*Model_simulation4.variablevalues(j,2), sim4_min(j));
            sim4_max(j) = max(scale.*Model_simulation4.variablevalues(j,2), sim4_max(j));
            sim5_min(j) = min(scale.*Model_simulation5.variablevalues(j,2), sim5_min(j));
            sim5_max(j) = max(scale.*Model_simulation5.variablevalues(j,2), sim5_max(j));
            pre1_min(j) = min(scale.*pre1_sim.variablevalues(j,2), pre1_min(j));
            pre1_max(j) = max(scale.*pre1_sim.variablevalues(j,2), pre1_max(j));
            pre2_min(j) = min(scale.*pre2_sim.variablevalues(j,2), pre2_min(j));
            pre2_max(j) = max(scale.*pre2_sim.variablevalues(j,2), pre2_max(j));
            pre3_min(j) = min(scale.*pre3_sim.variablevalues(j,2), pre3_min(j));
            pre3_max(j) = max(scale.*pre3_sim.variablevalues(j,2), pre3_max(j));
        end
        
        basal = 0; %one_hour_sim.statevalues(1,8);
        maxi = 1; %one_hour_sim.statevalues(end,8);
        
        for j = 1:size(one_min, 1)
            one_min(j) = min((one_hour_sim.statevalues(j,8)-basal)./maxi, one_min(j));
            one_max(j) = max((one_hour_sim.statevalues(j,8)-basal)./maxi, one_max(j));
        end
        for j = 1:size(twentytwo_min, 1)
            twentytwo_min(j) = min((twentytwo_hour_sim.statevalues(j,8)-basal)./maxi, twentytwo_min(j));
            twentytwo_max(j) = max((twentytwo_hour_sim.statevalues(j,8)-basal)./maxi, twentytwo_max(j)); 
        end
        for j = 1:size(p1n_min, 1)
            p1n_min(j) = min((pre1_sim.statevalues(j,8)-basal)./maxi, p1n_min(j));
            p1n_max(j) = max((pre1_sim.statevalues(j,8)-basal)./maxi, p1n_max(j));
        end
        for j = 1:size(p2n_min, 1)
            p2n_min(j) = min((pre2_sim.statevalues(j,8)-basal)./maxi, p2n_min(j));
            p2n_max(j) = max((pre2_sim.statevalues(j,8)-basal)./maxi, p2n_max(j));
        end
        
        for j = 1:size(p3n_min, 1)
            p3n_min(j) = min((pre3_sim.statevalues(j,8)-basal)./maxi, p3n_min(j));
            p3n_max(j) = max((pre3_sim.statevalues(j,8)-basal)./maxi, p3n_max(j));
        end
        
        %IKB
        basal = 0;
        maxi = one_hour_sim.statevalues(1,5);
        
        for j = 1:size(IKB0_min, 1)
            IKB0_max(j) = max(IKB0_max(j), (one_hour_sim.statevalues(j,5)-basal)./maxi);
            IKB0_min(j) = min(IKB0_min(j), (one_hour_sim.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKB22_min, 1)
            IKB22_max(j) = max(IKB22_max(j), (twentytwo_hour_sim.statevalues(j,5)-basal)./maxi);
            IKB22_min(j) = min(IKB22_min(j), (twentytwo_hour_sim.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKBbrown_min, 1)
            IKBbrown_max(j) = max(IKBbrown_max(j), (LPS_100_simulation.statevalues(j,5)-basal)./maxi);
            IKBbrown_min(j) = min(IKBbrown_min(j), (LPS_100_simulation.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKBpink_min, 1)
            IKBpink_max(j) = max(IKBpink_max(j), (Model_simulation5.statevalues(j,5)-basal)./maxi);
            IKBpink_min(j) = min(IKBpink_min(j), (Model_simulation5.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKBviolet_min, 1)
            IKBviolet_max(j) = max(IKBviolet_max(j), (pre2_sim.statevalues(j,5)-basal)./maxi);
            IKBviolet_min(j) = min(IKBviolet_min(j), (pre2_sim.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKBblue_min, 1)
            IKBblue_max(j) = max(IKBblue_max(j), (pre1_sim.statevalues(j,5)-basal)./maxi);
            IKBblue_min(j) = min(IKBblue_min(j), (pre1_sim.statevalues(j,5)-basal)./maxi);
        end
        for j = 1:size(IKBgreen_min, 1)
            IKBgreen_max(j) = max(IKBgreen_max(j), (Model_simulation3.statevalues(j,5)-basal)./maxi);
            IKBgreen_min(j) = min(IKBgreen_min(j), (Model_simulation3.statevalues(j,5)-basal)./maxi);
        end
    end
end

%% PLOT
figure(1)
subplot(2,2,1)
hold on
errorbar(EXPDATA.lps, EXPDATA.tnfa, EXPDATA.sem, 'ks','LineWidth', 2.5, 'MarkerFaceColor', 'k', 'MarkerSize', 8);
h = fill([EXPDATA.lps,flip(EXPDATA.lps)], [LPS_10_min,LPS_50_min,LPS_100_min,LPS_250_min,LPS_500_min,LPS_1000_min,LPS_1000_max,LPS_500_max,LPS_250_max,LPS_100_max,LPS_50_max,LPS_10_max], 'k');
set(h,'facealpha',.6,'EdgeColor','none')

title('A) LPS dose-response');
xlabel('LPS (ng/ml)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
set(gca, 'XScale', 'log')
axis([9, 1100, 0, 640]);

subplot(2,2,2)
hold on
errorbar(EXPDATA.timepoints, EXPDATA.tnfa1000, EXPDATA.sem1000,'s',  'Color', LPS1000, 'LineWidth', 2.5, 'MarkerFaceColor', LPS1000, 'MarkerSize', 8);
errorbar(EXPDATA.timepoints, EXPDATA.tnfa100, EXPDATA.sem100, 's', 'Color', LPS100, 'LineWidth', 2.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 8);
errorbar(EXPDATA.timepoints, EXPDATA.tnfaControl, EXPDATA.semControl, 's', 'Color', LPS0, 'LineWidth', 2.5, 'MarkerFaceColor', LPS0, 'MarkerSize', 8);
h = fill([LPS_1000_simulation.time,flip(LPS_1000_simulation.time)], ([LPS_1000_x_min;flip(LPS_1000_x_max)]'), LPS1000);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([LPS_100_simulation.time,flip(LPS_100_simulation.time)], ([LPS_100_x_min;flip(LPS_100_x_max)]'), LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([LPS_0_simulation.time,flip(LPS_0_simulation.time)], ([LPS_0_min;flip(LPS_0_max)]'), LPS0);
set(h,'facealpha',.6,'EdgeColor','none')

axis([0, 25, 0, 640]);
title('B) LPS time-response');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
LEG = legend('1000 ng/ml', '100 ng/ml', 'control (no LPS)', 'Location', 'northwest');
set(LEG,'FontSize',14);

subplot(2,2,3)
hold on
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfa100Control, DRUGDATA.sem100Control, 's', 'Color', LPS100, 'LineWidth', 2.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex_pre, DRUGDATA.semLowdex_pre, 's', 'Color', dexa03_pre, 'LineWidth', 2.5, 'MarkerFaceColor', dexa03_pre, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex_pre, DRUGDATA.semHighdex_pre, 's', 'Color', dexa3_pre3, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3_pre3, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex, DRUGDATA.semLowdex, 's', 'Color', dexa03, 'LineWidth', 2.5, 'MarkerFaceColor', dexa03, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex, DRUGDATA.semHighdex, 's', 'Color', dexa3, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3, 'MarkerSize', 8);
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([Dexa_min;flip(Dexa_max)]'), LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([sim2_min;flip(sim2_max)]'), dexa03);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([sim3_min;flip(sim3_max)]'), dexa3);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([sim4_min;flip(sim4_max)]'), dexa03_pre);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([sim5_min;flip(sim5_max)]'), dexa3_pre3);
set(h,'facealpha',.6,'EdgeColor','none')

axis([0, 25, 0, 640]);
title('C) Dexamethasone + LPS');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
LEG = legend('control (only LPS)', '0.3 uM (removed)', '3 uM (removed)', '0.3 uM', '3 uM', 'Location', 'northwest');
set(LEG,'FontSize',14);

subplot(2,2,4)
hold on
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBgreen_min;flip(IKBgreen_max)]'), dexa3);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBpink_min;flip(IKBpink_max)]'), dexa3_pre3);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBbrown_min;flip(IKBbrown_max)]'), LPS100);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([-1:0.001:0,flip(-1:0.001:0)], ([IKB0_min;flip(IKB0_max)]'), dexa3);
set(h,'facealpha',.5,'EdgeColor','none')
plot([0 0], [0 20], 'Color', LPS0, 'LineWidth', 0.5);

axis([-1, 25, 0, 4+IKBgreen_max(201)]);
title('D) Mechanism of sustained response');
xlabel('Time (hours)');
ylabel('I\kappaB\alpha, a.u.');
set(gca,'FontSize',14);
LEG = legend('3 uM Dexa', '3 uM Dexa (removed)', 'control (LPS)', 'Location', 'northeast');
set(LEG,'FontSize',14);

figure(11)
subplot(2,2,1)
hold on
errorbar(EXPDATA.lps, EXPDATA.tnfa, EXPDATA.sem, 'ks','LineWidth', 2.5, 'MarkerFaceColor', 'k', 'MarkerSize', 8);
h = fill([EXPDATA.lps,flip(EXPDATA.lps)], [LPS_10_min,LPS_50_min,LPS_100_min,LPS_250_min,LPS_500_min,LPS_1000_min,LPS_1000_max,LPS_500_max,LPS_250_max,LPS_100_max,LPS_50_max,LPS_10_max], 'k');
set(h,'facealpha',.6,'EdgeColor','none')

title('A) LPS dose-response');
xlabel('LPS (ng/ml)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
set(gca, 'XScale', 'log');
set(gca, 'YScale', 'log');
axis([9, 1100, 0, 640]);

subplot(2,2,2)
hold on
errorbar(EXPDATA.timepoints, EXPDATA.tnfa1000, EXPDATA.sem1000,'s',  'Color', LPS1000, 'LineWidth', 2.5, 'MarkerFaceColor', LPS1000, 'MarkerSize', 8);
errorbar(EXPDATA.timepoints, EXPDATA.tnfa100, EXPDATA.sem100, 's', 'Color', LPS100, 'LineWidth', 2.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 8);
errorbar(EXPDATA.timepoints, EXPDATA.tnfaControl, EXPDATA.semControl, 's', 'Color', LPS0, 'LineWidth', 2.5, 'MarkerFaceColor', LPS0, 'MarkerSize', 8);
h = fill([LPS_1000_simulation.time(2:end),flip(LPS_1000_simulation.time(2:end))], ([LPS_1000_x_min(2:end);flip(LPS_1000_x_max(2:end))]'), LPS1000);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([LPS_100_simulation.time(2:end),flip(LPS_100_simulation.time(2:end))], ([LPS_100_x_min(2:end);flip(LPS_100_x_max(2:end))]'), LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([LPS_0_simulation.time(2:end),flip(LPS_0_simulation.time(2:end))], ([LPS_0_min(2:end);flip(LPS_0_max(2:end))]'), LPS0);
set(h,'facealpha',.6,'EdgeColor','none')

axis([0, 25, 0, 640]);
title('B) LPS time-response');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
set(gca, 'YScale', 'log');
LEG = legend('1000 ng/ml', '100 ng/ml', 'control (no LPS)', 'Location', 'southeast');
set(LEG,'FontSize',14);

subplot(2,2,3)
hold on
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfa100Control, DRUGDATA.sem100Control, 's', 'Color', LPS100, 'LineWidth', 2.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex_pre, DRUGDATA.semLowdex_pre, 's', 'Color', dexa03_pre, 'LineWidth', 2.5, 'MarkerFaceColor', dexa03_pre, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex_pre, DRUGDATA.semHighdex_pre, 's', 'Color', dexa3_pre3, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3_pre3, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaLowdex, DRUGDATA.semLowdex, 's', 'Color', dexa03, 'LineWidth', 2.5, 'MarkerFaceColor', dexa03, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints, DRUGDATA.tnfaHighdex, DRUGDATA.semHighdex, 's', 'Color', dexa3, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3, 'MarkerSize', 8);
h = fill([Dexa_simulation.time(2:end),flip(Dexa_simulation.time(2:end))], ([Dexa_min(2:end);flip(Dexa_max(2:end))]'), LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time(2:end),flip(Dexa_simulation.time(2:end))], ([sim2_min(2:end);flip(sim2_max(2:end))]'), dexa03);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time(2:end),flip(Dexa_simulation.time(2:end))], ([sim3_min(2:end);flip(sim3_max(2:end))]'), dexa3);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time(2:end),flip(Dexa_simulation.time(2:end))], ([sim4_min(2:end);flip(sim4_max(2:end))]'), dexa03_pre);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([Dexa_simulation.time(2:end),flip(Dexa_simulation.time(2:end))], ([sim5_min(2:end);flip(sim5_max(2:end))]'), dexa3_pre3);
set(h,'facealpha',.6,'EdgeColor','none')

axis([0, 25, 0, 640]);
title('C) Dexamethasone + LPS');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
set(gca, 'YScale', 'log');
LEG = legend('control (only LPS)', '0.3 uM (removed)', '3 uM (removed)', '0.3 uM', '3 uM', 'Location', 'southeast');
set(LEG,'FontSize',14);

subplot(2,2,4)
hold on
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBgreen_min;flip(IKBgreen_max)]'), dexa3);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBpink_min;flip(IKBpink_max)]'), dexa3_pre3);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([Dexa_simulation.time,flip(Dexa_simulation.time)], ([IKBbrown_min;flip(IKBbrown_max)]'), LPS100);
set(h,'facealpha',.5,'EdgeColor','none')
h = fill([-1:0.001:0,flip(-1:0.001:0)], ([IKB0_min;flip(IKB0_max)]'), dexa3);
set(h,'facealpha',.5,'EdgeColor','none')
plot([0 0], [0 20], 'Color', LPS0, 'LineWidth', 0.5);

axis([-1, 25, 0, max(IKBgreen_max)]);
title('D) Mechanism of sustained response');
xlabel('Time (hours)');
ylabel('I\kappaB\alpha, a.u.');
set(gca,'FontSize',14);
set(gca, 'YScale', 'log');
LEG = legend('3 uM Dexa', '3 uM Dexa (removed)', 'control (LPS)', 'Location', 'southeast');
set(LEG,'FontSize',14);


figure(2)
subplot(2,1,1)
hold on
h = fill([0:0.025:6, flip(0:0.025:6)], [Dexa_min(1:241);flip(Dexa_max(1:241))]', LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([1:7/1000:8, flip(1:7/1000:8)],[pre3_min; flip(pre3_max)]',  dexa3_pre3);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([17:7/1000:24, flip(17:7/1000:24)],[pre2_min; flip(pre2_max)]',  dexa3_pre2);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([23:7/1000:30, flip(23:7/1000:30)],[pre1_min; flip(pre1_max)]',  dexa3_pre1);
set(h,'facealpha',.6,'EdgeColor','none')
axis([0, 30, 0, max([Dexa_max(241),pre1_max(end)])+1]);

title('Model predictions: Dexamethasone, pre-treatments + LPS');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
LEG = legend('control (only LPS)', 'dexa removed before LPS', '16 h wash before LPS', '22 h wash before LPS', 'Location', 'north');
set(LEG,'FontSize',14);

subplot(2,1,2)
hold on
errorbar(DRUGDATA.timepoints2, DRUGDATA.pre_control_tnfa, DRUGDATA.pre_control_sem, 's', 'Color', LPS100, 'LineWidth', 2.5, 'MarkerFaceColor', LPS100, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints2 + 1, DRUGDATA.pre3_tnfa, DRUGDATA.pre3_sem, 's', 'Color', dexa3_pre3, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3_pre3, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints2 + 17, DRUGDATA.pre2_tnfa, DRUGDATA.pre2_sem, 's', 'Color', dexa3_pre2, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3_pre2, 'MarkerSize', 8);
errorbar(DRUGDATA.timepoints2 + 23, DRUGDATA.pre1_tnfa, DRUGDATA.pre1_sem, 's', 'Color', dexa3_pre1, 'LineWidth', 2.5, 'MarkerFaceColor', dexa3_pre1, 'MarkerSize', 8);
axis([0, 30, 0, max([Dexa_max(241),pre1_max(end)])+1]);
plot([6 7], [120 120], 'Color', LPS0, 'LineWidth', 0.5);
plot([6 6], [210-5 210+5], 'Color', LPS0, 'LineWidth', 0.5);
plot([7 7], [120-5 120+5], 'Color', LPS0, 'LineWidth', 0.5);
plot([6 29], [210 210], 'Color', LPS0, 'LineWidth', 0.5);
plot([29 29], [210-5 210+5], 'Color', LPS0, 'LineWidth', 0.5);
plot([6 6], [120-5 120+5], 'Color', LPS0, 'LineWidth', 0.5);
text(6.5, 100, 'p = 0.0047','FontSize',14)
text(27, 190, 'p = 0.034','FontSize',14)

title('Experimental data: Dexamethasone, pre-treatments + LPS');
xlabel('Time (hours)');
ylabel('TNF (pg/mg tissue)');
set(gca,'FontSize',14);
LEG = legend('control (only LPS)', 'dexa removed before LPS', '16 h wash before LPS', '22 h wash before LPS', 'Location', 'best');
set(LEG,'FontSize',14);

orderp = [1,3,4,8,7,2,11,10,9,14,15,12,13,5,6,16,17,18];
figure(3)
semilogy(1:size(all_param,2)-1,all_param(:,1+orderp),'-o')
set(gca,'XTick',1:size(all_param,2)-1)
set(gca,'XTickLabel',[paramNames(orderp(1:end-1));'scale'])
set(gca,'XTickLabelRotation',45)
ylabel('Parameter values');
set(gca,'FontSize',14);
axis([0, size(all_param,2), 9e-4, 2e3]);

figure(5)
hold on
h = fill([0:0.025:25, flip(0:0.025:25)], [IKBbrown_min;flip(IKBbrown_max)]', LPS100);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([1:0.025:26, flip(1:0.025:26)],[IKBpink_min; flip(IKBpink_max)]',  dexa3_pre3);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([17:7/1000:24, flip(17:7/1000:24)],[IKBviolet_min; flip(IKBviolet_max)]',  dexa3_pre2);
set(h,'facealpha',.6,'EdgeColor','none')
h=fill([23:7/1000:30, flip(23:7/1000:30)],[IKBblue_min; flip(IKBblue_max)]',  dexa3_pre1);
h = fill([0:1/1000:1, flip(0:1/1000:1)], [IKB0_min;flip(IKB0_max)]', LPS0);
set(h,'facealpha',.6,'EdgeColor','none')
h = fill([1:22/1000:23, flip(1:22/1000:23)], [IKB22_min;flip(IKB22_max)]', LPS0);
set(h,'facealpha',.6,'EdgeColor','none')
set(h,'facealpha',.6,'EdgeColor','none')
axis([0, 30, 0, max(IKB22_max)]);

title('Model predictions: Dexamethasone, pre-treatments + LPS');
xlabel('Time (hours)');
ylabel('I\kappaB\alpha, a.u.');
set(gca,'FontSize',14);
LEG = legend('control (only LPS)', 'dexa removed before LPS', '16 h wash before LPS', '22 h wash before LPS', 'Location', 'north');
set(LEG,'FontSize',14);
